@@ -24,7 +24,7 @@ function select_range_init()
 {
 
    if (!@include_once (SM_PATH . 'plugins/select_range/config.php'))
-      if (!@include_once (SM_PATH . 'plugins/select_range/config_default.php'))
+      if (!@include_once (SM_PATH . 'plugins/select_range/config.sample.php'))
          return FALSE;
 
    return TRUE;
@@ -543,7 +543,7 @@ function select_range_generate_link($hook_arguments)
             include(SM_PATH . 'plugins/select_range/templates/default/select_range_link.tpl');
             $link = ob_get_contents();
             ob_end_clean();
-            return '|&nbsp;' . $link . '&nbsp;';
+            return '|&nbsp;' . $link;
          }
 
       }
